This is a module that is made by a middle schooler in 6th grade based on the topics that he has covered and his knowledge, information and interest in the programming 

touch LICENSE
touch pyproject.toml
touch setup.cfg
mkdir src/mypackage
touch src/mypackage/__init__.py
touch src/mypackage/main.py
mkdir tests